@@ -1,4 +1,4 @@
-/*  $Id: BurgerSpaceServer.cpp,v 1.9 2013/02/25 05:04:43 sarrazip Exp $
+/*  $Id: BurgerSpaceServer.cpp,v 1.11 2019/08/09 00:06:34 sarrazip Exp $
     BurgerSpaceServer.cpp - Main engine
 
     burgerspace - A hamburger-smashing video game.
@@ -733,7 +733,7 @@ BurgerSpaceServer::Level::getTextDescription() const
 
 
 BurgerSpaceServer::BurgerSpaceServer(int initLevelNumber,
-                                    bool _oldMotionMode) throw(int, string)
+                                    bool _oldMotionMode)
   : theScreenSizeInPixels(SCREEN_WIDTH_IN_PIXELS, SCREEN_HEIGHT_IN_PIXELS),
 
     initLevelNo(1),
@@ -830,7 +830,7 @@ BurgerSpaceServer::finishInit()
 
 
 void
-BurgerSpaceServer::displayErrorMessage(const string &msg) throw()
+BurgerSpaceServer::displayErrorMessage(const string &msg)
 {
     cerr << msg << endl;
 }
@@ -871,7 +871,7 @@ BurgerSpaceServer::createPlayerSprite()
 
 
 void
-BurgerSpaceServer::initializeSprites() throw(PixmapLoadError)
+BurgerSpaceServer::initializeSprites()
 /*  Initializes the sprites that appear at the beginning of a level,
     like the ingredients.
 
@@ -930,7 +930,7 @@ BurgerSpaceServer::initializeSprites() throw(PixmapLoadError)
 
 
 void
-BurgerSpaceServer::initializeMisc() throw(string)
+BurgerSpaceServer::initializeMisc()
 /*  Initializes things that need to be initialized once, but not at the
     beginning of each level.
 
@@ -1160,7 +1160,7 @@ BurgerSpaceServer::putSprite(const Sprite &s)
 
 
 void
-BurgerSpaceServer::initNextLevel(int levelNo /*= 0*/) throw(int)
+BurgerSpaceServer::initNextLevel(int levelNo /*= 0*/)
 /*  Initialize the next level.  Increments the current level number if
     levelNo is zero, or uses levelNo if it is positive.
 */
@@ -2118,7 +2118,7 @@ BurgerSpaceServer::moveEnemyList(SpriteList &slist, int speedFactor)
             if (numDirectionsAllowed == 0)
             {
                 belowStructure = true;
-                allowedDirections[UP]++;
+                allowedDirections[UP] = true;
             }
         }
 
@@ -2331,7 +2331,9 @@ BurgerSpaceServer::releaseAllCarriedEnemies()
 void
 BurgerSpaceServer::detectCollisions()
 {
-    if (playerSprite != NULL && playerSprite->getTimeToLive() != 0)  // if player is agonizing
+    if (playerSprite == NULL)  // if player is dead
+        return;
+    if (playerSprite->getTimeToLive() != 0)  // if player is agonizing
         return;
 
     bool playIngredientLoweredSound = false;
@@ -2643,7 +2645,7 @@ BurgerSpaceServer::createScoreSprites(long n, Couple center)
 static void
 loadPixmap(const char **xpmData,
                 SDL_Surface *&pixmap,
-                Couple &pixmapSize) throw(PixmapLoadError)
+                Couple &pixmapSize)
 {
     pixmapSize.zero();
 
@@ -2661,7 +2663,6 @@ loadPixmap(const char **xpmData,
 
 static void
 loadPixmap(const char **xpmData, PixmapArray &pa, size_t index)
-                                                throw(PixmapLoadError)
 {
     // Masks are not be relevant with SDL.
 
@@ -2674,7 +2675,7 @@ loadPixmap(const char **xpmData, PixmapArray &pa, size_t index)
 
 
 void
-BurgerSpaceServer::loadPixmaps() throw(PixmapLoadError)
+BurgerSpaceServer::loadPixmaps()
 {
     /*  Load the player pixmaps:
 
@@ -2813,7 +2814,7 @@ BurgerSpaceServer::loadPixmaps() throw(PixmapLoadError)
 
 
 void
-BurgerSpaceServer::loadLevel(int levelNo) throw(string)
+BurgerSpaceServer::loadLevel(int levelNo)
 /*  Affects the data member 'theCurrentLevel', which must already be
     initialized to defined values.
     'levelNo' may exceed NUM_LEVELS.
