@@ -1,4 +1,4 @@
-/*  $Id: server.cpp,v 1.3 2010/09/16 03:22:22 sarrazip Exp $
+/*  $Id: server.cpp,v 1.5 2018/06/24 20:53:05 sarrazip Exp $
     server.cpp - main() function for BurgerSpace server
 
     burgerspace - A hamburger-smashing video game.
@@ -304,7 +304,7 @@ class BurgerSpaceCommandLineServer : public BurgerSpaceServer
 {
 public:
 
-    BurgerSpaceCommandLineServer(int _initLevelNumber, int _sock, Uint32 _minMSBetweenWrites) throw(int, std::string)
+    BurgerSpaceCommandLineServer(int _initLevelNumber, int _sock, Uint32 _minMSBetweenWrites)
       : BurgerSpaceServer(_initLevelNumber, false),
         sock(_sock),
         minMSBetweenWrites(_minMSBetweenWrites),
@@ -892,7 +892,7 @@ main(int argc, char *argv[])
         server.sin_family = AF_INET;
         server.sin_addr.s_addr = INADDR_ANY;
         server.sin_port = htons(port);
-        if (bind(sock, (sockaddr *) &server, sizeof(server)) < 0)
+        if (::bind(sock, (sockaddr *) &server, sizeof(server)) < 0)
         {
             int e = errno;
             cout << PROGRAM << ": failed to bind to server port " << port << ": " << strerror(e) << endl;
